"""The idlelib package implements the Idle application.

Idle includes an interactive shell and editor.
Use the files named idle.* to start Idle.

The other files are private implementations.  Their details are subject
to change.  See PEP 434 for more.  Import them at your own risk.
"""
